@@ -32,8 +32,9 @@
 
 (declare-function agent-shell--indent-string "agent-shell")
 (declare-function agent-shell-make-agent-config "agent-shell")
+(autoload 'agent-shell-make-agent-config "agent-shell")
 (declare-function agent-shell--make-acp-client "agent-shell")
-(declare-function agent-shell-start "agent-shell")
+(declare-function agent-shell--dwim "agent-shell")
 
 (cl-defun agent-shell-make-goose-authentication (&key openai-api-key none)
   "Create Goose authentication configuration.
@@ -69,7 +70,7 @@ For no authentication (when using alternative authentication methods):
   :type 'alist
   :group 'agent-shell)
 
-(defcustom agent-shell-goose-command
+(defcustom agent-shell-goose-acp-command
   '("goose" "acp")
   "Command and parameters for the Goose client.
 
@@ -98,6 +99,7 @@ Example usage to set custom environment variables:
 
 Returns an agent configuration alist using `agent-shell-make-agent-config'."
   (agent-shell-make-agent-config
+   :identifier 'goose
    :mode-line-name "Goose"
    :buffer-name "Goose"
    :shell-prompt "Goose> "
@@ -111,8 +113,8 @@ Returns an agent configuration alist using `agent-shell-make-agent-config'."
 (defun agent-shell-goose-start-agent ()
   "Start an interactive Goose agent shell."
   (interactive)
-  (agent-shell-start
-   :config (agent-shell-goose-make-agent-config)))
+  (agent-shell--dwim :config (agent-shell-goose-make-agent-config)
+                     :new-shell t))
 
 (cl-defun agent-shell-goose-make-client (&key buffer)
   "Create a Goose client using configured authentication with BUFFER as context.
@@ -120,9 +122,11 @@ Returns an agent configuration alist using `agent-shell-make-agent-config'."
 Uses `agent-shell-goose-authentication' for authentication configuration."
   (unless buffer
     (error "Missing required argument: :buffer"))
+  (when (and (boundp 'agent-shell-goose-command) agent-shell-goose-command)
+    (user-error "Please migrate to use agent-shell-goose-acp-command and eval (setq agent-shell-goose-command nil)"))
   (let ((api-key (agent-shell-goose-key)))
-    (agent-shell--make-acp-client :command (car agent-shell-goose-command)
-                                  :command-params (cdr agent-shell-goose-command)
+    (agent-shell--make-acp-client :command (car agent-shell-goose-acp-command)
+                                  :command-params (cdr agent-shell-goose-acp-command)
                                   :environment-variables (append (cond ((map-elt agent-shell-goose-authentication :none)
                                                                         nil)
                                                                        (api-key
@@ -165,8 +169,8 @@ Uses `agent-shell-goose-authentication' for authentication configuration."
 ╰───╮ │ ╰─────╯ ╰─────╯ ╰─────╯ ╰─────╯
     ╰─╯" "\n")))
     (propertize text 'font-lock-face (if is-dark
-                                         '(:foreground "#a0a0a0")
-                                       '(:foreground "#505050")))))
+                                         '(:foreground "#a0a0a0" :inherit fixed-pitch)
+                                       '(:foreground "#505050" :inherit fixed-pitch)))))
 
 (provide 'agent-shell-goose)
 
